@@ -63,6 +63,7 @@ class EnexUploader(object):
         done_file: Path,
         add_meta: bool,
         add_pdf_preview: bool,
+        condense_lines: bool,
     ):
         self.import_root = import_root
         self.mode = mode
@@ -70,6 +71,7 @@ class EnexUploader(object):
         self.done_hashes = DoneFile(done_file) if done_file else set()
         self.add_meta = add_meta
         self.add_pdf_preview = add_pdf_preview
+        self.condense_lines = condense_lines
 
     def upload(self, enex_file: Path):
         logger.info(f"Processing notebook '{enex_file.stem}'...")
@@ -96,6 +98,7 @@ class EnexUploader(object):
                 mode_webclips=self.mode_webclips,
                 is_add_meta=self.add_meta,
                 is_add_pdf_preview=self.add_pdf_preview,
+                is_condense_lines=self.condense_lines,
             )
         except Exception:
             logger.error(f"Unhandled exception while parsing note '{note.title}'!")
@@ -128,6 +131,7 @@ def cli(argv):
         done_file=args.done_file,
         add_meta=args.add_meta,
         add_pdf_preview=args.add_pdf_preview,
+        condense_lines=args.condense_lines,
     )
 
     for enex_input in args.enex_input:
@@ -213,6 +217,14 @@ def parse_args(argv):
                 " makes sense only with PAGE mode"
             ),
         },
+        "--condense-lines": {
+            "action": "store_true",
+            "default": False,
+            "help": (
+                "condense text lines together into paragraphs"
+                " to avoid making block per line"
+            ),
+        },
         "--done-file": {
             "type": Path,
             "metavar": "FILE",
