@@ -1,9 +1,10 @@
 import logging
 
 from notion.block import CollectionViewPageBlock, PageBlock
+from notion.client import NotionClient
 from notion.collection import CollectionRowBlock
 from progress.bar import Bar
-from requests import HTTPError
+from requests import HTTPError, codes
 
 from enex2notion.enex_types import EvernoteNote
 from enex2notion.note_uploader import upload_block
@@ -15,8 +16,27 @@ class NoteUploadFailException(Exception):
     """Exception for when a note fails to upload"""
 
 
+class BadTokenException(Exception):
+    """Exception for when a token is invalid"""
+
+
+def get_notion_client(token):
+    try:
+        return NotionClient(token_v2=token)
+    except HTTPError as e:  # pragma: no cover
+        if e.response.status_code == codes["unauthorized"]:
+            raise BadTokenException
+        raise
+
+
 def get_import_root(client, title):
-    for page in client.get_top_level_pages():
+    try:
+        top_pages = client.get_top_level_pages()
+    except KeyError:  # pragma: no cover
+        # Need empty account to test
+        top_pages = []
+
+    for page in top_pages:
         if isinstance(page, PageBlock) and page.title == title:
             logger.info(f"'{title}' page found")
             return page
